==> discover-5.5.0.tar.xz: discover-5.5.0/libdiscover/Category/CategoriesReader.h <==
/***************************************************************************
 *   Copyright © 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef CATEGORIESREADER_H
#define CATEGORIESREADER_H
#include <QList>

class Category;
class CategoriesReader
{
    public:
        QList<Category*> populateCategories();

    private:
        QList<Category*> loadCategoriesFile(const QString& path);
};

#endif // CATEGORIESREADER_H

==> discover-5.7.3.tar.xz: discover-5.7.3/libdiscover/Category/CategoriesReader.h <==
/***************************************************************************
 *   Copyright © 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef CATEGORIESREADER_H
#define CATEGORIESREADER_H

#include <QVector>
#include "discovercommon_export.h"

class Category;
class DISCOVERCOMMON_EXPORT CategoriesReader
{
    public:
        QVector<Category*> populateCategories();
        QVector<Category*> loadCategoriesPath(const QString& path);

        static bool categoryLessThan(Category *c1, const Category *c2);

    private:
        QVector<Category*> loadCategoriesFile(const QString& path);
};

#endif // CATEGORIESREADER_H
